#!/usr/bin/env python

# Copyright (C) 2006-2014 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

import subprocess
from agent.lib.db import read_item
from agent.lib.constants import LOCAL_SERVER_DB
from agent.target.host import get_ovs_info
from agent.target.hypervisor import get_hv_info

# Output all the stuff we need; parsed in ovs-snmp

unconfigured = False
try:
    read_item(LOCAL_SERVER_DB, "manager_uuid")
except:
    unconfigured = True

print "type=Oracle VM Server"
print "version=%s" % get_ovs_info()['release']

agentstatus = subprocess.call(['/etc/init.d/ovs-agent', 'status'])

try:
    hostname = read_item(LOCAL_SERVER_DB, "registered_hostname")
except:
    hostname = "None"

if not unconfigured:
    current_state = read_item(LOCAL_SERVER_DB, "cluster_state")
    isClustered = read_item(LOCAL_SERVER_DB, "clustered")
    mgrUUID = read_item(LOCAL_SERVER_DB, "manager_uuid")
    if not mgrUUID:
        mgr_uuid = "Unowned"
    else:
        mgr_uuid = mgrUUID
    pool_alias = read_item(LOCAL_SERVER_DB, "pool_alias")
    if isClustered:
        cluster = "Yes"
    else:
        cluster = "No"
    poolfs_target = read_item(LOCAL_SERVER_DB, "poolfs_target")
    poolfs_type = read_item(LOCAL_SERVER_DB, "poolfs_type")
    print "clusterstate=%s" % current_state
    print "clusterType=%s" % poolfs_type
    print "clusterStorage=%s" % poolfs_target
    print "managerUUID=%s" % mgr_uuid
    print "serverpoolname=%s" % pool_alias
else:
    print "clusterstate=None"
    print "clusterType=None"
    print "clusterStorage=None"
    print "managerUUID=Unowned"
    print "serverpoolname=None"

if agentstatus == 0:
    print "agentstate=Running"
else:
    print "agentstate=Down"

xeninfo = get_hv_info()
sysmem = xeninfo['total_memory']
freemem = xeninfo['free_memory']
print "freemem=%s" % freemem
